==> kxmleditor-0.7.2.tar.gz: kxmleditor-0.7.2/part/dcopiface_part_ro.cpp <==
/***************************************************************************
                          dcopiface_part_ro.cpp  -  description
                             -------------------
    begin                : Tue Oct 23 2001
    copyright            : (C) 2001 by The KXMLEditor Team
    email                : lvanek@eanet.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "dcopiface_part_ro.h"
#include "kxmleditorpart.h"
//---------------------------------------------------------------------------
// KXMLEditorPartIfaceReadOnly
//---------------------------------------------------------------------------
QString
KXMLEditorPartIfaceReadOnly::saveAsFile(const QString & path_to_file)
{
	return "Not implemented.";
}

QString
KXMLEditorPartIfaceReadOnly::selectNode(const QString & szPathToNode)
{
	m_pKXEPart->slotPathSelected(szPathToNode);

	if ( m_pKXEPart->getSelectedPath() == szPathToNode )
		return "Selecting node failed.";

	return QString();
}

QString
KXMLEditorPartIfaceReadOnly::currentNode() const
{
	return m_pKXEPart->getSelectedPath();
}


//---------------------------------------------------------------------------
// KXMLEditorPartIface
//---------------------------------------------------------------------------
QString
KXMLEditorPartIfaceReadWrite::openURL(const QString  & szURL)
{
	KURL url(szURL);
	if (! url.isValid () ) //Hope it is negation of bool isMalformed()
		return "URL is not valid.";
	if ( m_pKXEPart->openURL(url) )
		return QString();
	else
		return "Opening URL failed.";
}


QString
KXMLEditorPartIfaceReadWrite::close()
{
	return "Not implemented.";
}

==> kxmleditor_1.0.0.orig.tar.gz: kxmleditor-1.0.0/part/dcopiface_part_ro.cpp <==
/***************************************************************************
                          dcopiface_part_ro.cpp  -  description
                             -------------------
    begin                : Tue Oct 23 2001
    copyright            : (C) 2001, 2002, 2003 by The KXMLEditor Team
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "dcopiface_part_ro.h"
#include "kxmleditorpart.h"
//---------------------------------------------------------------------------
// KXMLEditorPartIfaceReadOnly
//---------------------------------------------------------------------------
QString
KXMLEditorPartIfaceReadOnly::saveAsFile(const QString & path_to_file)
{
	return "Not implemented.";
}

QString
KXMLEditorPartIfaceReadOnly::selectNode(const QString & szPathToNode)
{
	m_pKXEPart->slotPathSelected(szPathToNode);

	if ( m_pKXEPart->getSelectedPath() == szPathToNode )
		return "Selecting node failed.";

	return QString();
}

QString
KXMLEditorPartIfaceReadOnly::currentNode() const
{
	return m_pKXEPart->getSelectedPath();
}


//---------------------------------------------------------------------------
// KXMLEditorPartIface
//---------------------------------------------------------------------------
QString
KXMLEditorPartIfaceReadWrite::openURL(const QString  & szURL)
{
	KURL url(szURL);
	if (! url.isValid () ) //Hope it is negation of bool isMalformed()
		return "URL is not valid.";
	if ( m_pKXEPart->openURL(url) )
		return QString();
	else
		return "Opening URL failed.";
}


QString
KXMLEditorPartIfaceReadWrite::close()
{
	return "Not implemented.";
}
